@@ -38,6 +38,8 @@ Uploaded with FRC-YouTube-Uploader (https://github.com/NikhilNarayana/FRC-YouTub
 VALID_PRIVACY_STATUSES = ("public", "unlisted", "private")
 
 GAMES = {
+    "2023": "FIRST ENERGIZE: Charged Up, Charged Up, CHARGED UP",
+    "2022": "Rapid React, RAPID REACT",
     "2021": "FIRST Rise: Infinite Recharge, Rise: INFINITE RECHARGE, INFINITE RECHARGE",
     "2020": "FIRST Rise: Infinite Recharge, Rise: INFINITE RECHARGE, INFINITE RECHARGE",
     "2019": "FIRST Destination: Deep Space, Destination: Deep Space, Deep Space",
@@ -72,8 +74,13 @@ cerem = (
     "Closing Ceremonies",
     "Highlight Reel",
 )
-root = os.path.join(os.path.expanduser("~"), ".frcuploader")
-queue_values = os.path.join(root, ".frc_queue_values.txt")
-form_values = os.path.join(root, ".frc_form_values.json")
-log_file = os.path.join(root, ".frc_log.txt")
+
+frc_folder = os.path.join(os.path.expanduser("~"), ".frcuploader")
+yt_accounts_folder = os.path.join(frc_folder, "accounts")
+youtube_oauth_file = os.path.join(frc_folder, "frc-oauth2-youtube.json")
+os.makedirs(yt_accounts_folder, exist_ok=True)
+
+queue_values = os.path.join(frc_folder, "frc_queue_values.txt")
+form_values = os.path.join(frc_folder, "frc_form_values.json")
+log_file = os.path.join(frc_folder, "frc_log.txt")
 rec_formats = (".ts", ".mkv", ".avi", ".mp4", ".flv", ".mov")
